@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby-1.4
 #
 # extconf.rb for ldap extension
-# $Id: extconf.rb,v 1.3 2003/09/05 17:13:14 ttate Exp $
+# $Id: extconf.rb,v 1.4 2005/02/23 05:30:49 ianmacd Exp $
 #
 
 require 'mkmf'
@@ -275,5 +275,14 @@ test-clean::
 
 reconfig::
 \t$(RUBY_INSTALL_NAME) $(srcdir)/extconf.rb #{ARGV.join(" ")}
+
+doc:
+#\t$(RUBY_INSTALL_NAME) -rrdoc/ri/ri_paths -e 'puts RI::Paths::PATH[0]'
+\trdoc --ri-site *.c lib/ldap
+
+unit:
+\t(cd test; $(RUBY_INSTALL_NAME) tc_ldif.rb)
+
+.PHONY:	doc
 EOF
 }
