@@ -39,7 +39,7 @@ def install()
 
   rb_files.each{|f|
     origfile = f
-    instfile = File.join($rubylibdir, origfile.sub("./lib/",""))
+    instfile = File.join($rubylibdir, origfile.sub(%r{./lib/},""))
     instdir  = File.dirname(instfile)
     File.makedirs(instdir)
     File.install(origfile, instfile, 0644, true)
